pub(crate) struct BridgeSet {
config: Arc<[BridgeConfig]>,
descs: Option<Arc<BridgeDescList>>,
}Expand description
A collection of bridges, possibly with their descriptors.
Fields
config: Arc<[BridgeConfig]>The configured bridges.
descs: Option<Arc<BridgeDescList>>A map from those bridges to their descriptors. It may contain elements
that are not in config.
Implementations
Sourceimpl BridgeSet
impl BridgeSet
Sourcepub(crate) fn new(
config: Arc<[BridgeConfig]>,
descs: Option<Arc<BridgeDescList>>,
) -> Self
pub(crate) fn new( config: Arc<[BridgeConfig]>, descs: Option<Arc<BridgeDescList>>, ) -> Self
Create a new BridgeSet from its configuration.
Sourcepub(crate) fn bridge_by_guard<T>(&self, guard: &T) -> Option<&BridgeConfig>where
T: ChanTarget,
pub(crate) fn bridge_by_guard<T>(&self, guard: &T) -> Option<&BridgeConfig>where
T: ChanTarget,
Returns the bridge that best matches a given guard.
Note that since the guard may have more identities than the bridge the match may not be perfect: the caller needs to check for a closer match if they want to be certain.
We check for a match by identity and channel method, since channel method is part of what makes two bridge lines different.
Sourcefn relay_by_bridge<'a>(&'a self, bridge: &'a BridgeConfig) -> BridgeRelay<'a>
fn relay_by_bridge<'a>(&'a self, bridge: &'a BridgeConfig) -> BridgeRelay<'a>
Return a BridgeRelay wrapping the provided configuration, plus any known descriptor for that configuration.
Sourcepub(crate) fn bridge_relay_by_guard<T: ChanTarget>(
&self,
guard: &T,
) -> CandidateStatus<BridgeRelay<'_>>
pub(crate) fn bridge_relay_by_guard<T: ChanTarget>( &self, guard: &T, ) -> CandidateStatus<BridgeRelay<'_>>
Look up a BridgeRelay corresponding to a given guard.