#[non_exhaustive]#[repr(u16)]pub enum BridgeDescEvent {
SomethingChanged = 0,
}Available on crate feature
bridge-client only.Expand description
An event describing a change in a BridgeDescList.
Currently changes are always reported as BridgeDescEvent::SomethingChanged.
In the future, as an optimization, more fine-grained information may be provided.
Unrecognized variants should be handled the same way as SomethingChanged.
(So right now, it is not necessary to match on the variant at all.)
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
SomethingChanged = 0
Some change occurred to the set of descriptors
The return value from bridges()
may have changed.
The nature of the change is not specified; it might affect multiple descriptors, and include multiple different kinds of change.
This event may also be generated spuriously, if nothing has changed, but this will usually be avoided for performance reasons.