pub struct BridgeConfig(/* private fields */);bridge-client only.Expand description
A relay not listed on the main tor network, used for anticensorship.
This object represents a bridge as configured by the user or by software running on the user’s behalf.
Pieces of a bridge configuration.
A bridge configuration contains:
- Optionally, the name of a pluggable transport (q.v.) to use.
- Zero or more addresses at which to contact the bridge. These can either be regular IP addresses, hostnames, or arbitrary strings to be interpreted by the pluggable transport.
- One or more cryptographic identities for the bridge.
- Zero or more optional “key=value” string parameters to pass to the pluggable transport when contacting to this bridge.
String representation
Can be parsed from, and represented as, a “bridge line” string,
using the FromStr and Display implementations.
The syntax supported is a sequence of words, separated by ASCII whitespace, in the following order:
-
Optionally, the word
Bridge(or a case variant thereof). (Bridgeis not part of a bridge line, but is ignored here for convenience when copying a line out of a C Tortorrc.) -
Optionally, the name of the pluggable transport to use. If not supplied, Arti will make the connection directly, itself.
-
The
Host:ORPortto connect to.Hostcan be an IPv4 address, or an IPv6 address in brackets[ ]. When a pluggable transport is in use,Hostcan also be a hostname; or if the transport supports operating without a specified address.Host:ORPortcan be omitted and replaced with-. -
One or more identity key fingerprints, each in one of the supported (RSA or ed25519) fingerprint formats. Currently, supplying an RSA key is required; an ed25519 key is optional.
-
When a pluggable transport is in use, zero or more
key=valueparameters to pass to the transport (smuggled in the SOCKS handshake, as described in the Tor PT specification).
This type is cheap to clone: it is a newtype around an Arc.
Implementations
Sourceimpl BridgeConfig
impl BridgeConfig
Sourcepub fn builder() -> BridgeConfigBuilder
pub fn builder() -> BridgeConfigBuilder
Returns a fresh, default, builder