pub trait BridgeDescError:
Error
+ DynClone
+ HasKind
+ HasRetryTime
+ Send
+ Sync
+ 'static { }Expand description
An error caused while fetching bridge descriptors
Note that when this appears in BridgeDescList, as returned by BridgeDescMgr,
the fact that this is HasRetryTime does not mean the caller should retry.
Retries will be handled by the BridgeDescMgr.
The HasRetryTime impl can be used as a guide to
whether the situation is likely to improve soon.
Does not include the information about which bridge we were trying to get a descriptor for.