pub(crate) struct DirStatus {
delay: RetryDelay,
retry_at: Option<Instant>,
}Expand description
Status information about whether a
FallbackDir or
Guard is currently usable as a directory cache.
This structure is used to track whether the cache has recently failed, and if so, when it can be retried.
Fields
delay: RetryDelayUsed to decide how long to delay before retrying a fallback cache that has failed.
retry_at: Option<Instant>A time before which we should assume that this fallback cache is broken.
If None, then this fallback cache is ready to use right away.
Implementations
Sourceimpl DirStatus
impl DirStatus
Sourcepub(crate) fn new(delay_floor: Duration) -> Self
pub(crate) fn new(delay_floor: Duration) -> Self
Construct a new DirStatus object with a given lower-bound for delays after failure.
Sourcepub(crate) fn usable_at(&self, now: Instant) -> bool
pub(crate) fn usable_at(&self, now: Instant) -> bool
Return true if this Status is usable at the time now.
Sourcepub(crate) fn next_retriable(&self) -> Option<Instant>
pub(crate) fn next_retriable(&self) -> Option<Instant>
Return the time at which this Status can next be retried.
A return value of None, or of a time in the past, indicates that this
status can be used immediately.
Sourcepub(crate) fn note_success(&mut self)
pub(crate) fn note_success(&mut self)
Record that the associated fallback directory has been used successfully.
This should only be done after successfully handling a whole reply from the directory.
Sourcepub(crate) fn note_failure(&mut self, now: Instant)
pub(crate) fn note_failure(&mut self, now: Instant)
Record that the associated fallback directory has failed.