pub(crate) enum GuardSetSelector {
Default,
Restricted,
Bridges,
}Expand description
A selector that tells us which GuardSet of several is currently in use.
Variants
Default
The default guard set is currently in use: that’s the one that we use when we have no filter installed, or the filter permits most of the guards on the network.
Restricted
A “restrictive” guard set is currently in use: that’s the one that we use when we have a filter that excludes a large fraction of the guards on the network.
Bridges
The “bridges” guard set is currently in use: we are selecting our guards from among the universe of configured bridges.
Implementations
Sourceimpl GuardSetSelector
impl GuardSetSelector
Sourcepub(crate) fn universe_type(&self) -> UniverseType
pub(crate) fn universe_type(&self) -> UniverseType
Return a description of which Universe this guard sample should take
its guards from.