enum SingleFilter {
ReachableAddrs(Vec<AddrPortPattern>),
}Expand description
A single restriction places upon usable guards.
Variants
ReachableAddrs(Vec<AddrPortPattern>)
A set of allowable addresses that we are willing to try to connect to.
This list of patterns has “or” semantics: a guard is permitted by this filter if ANY pattern in this list permits one of the guard’s addresses.
Implementations
Sourceimpl SingleFilter
impl SingleFilter
Sourcefn permits<C: ChanTarget>(&self, target: &C) -> bool
fn permits<C: ChanTarget>(&self, target: &C) -> bool
Return true if this filter permits the provided target.
Sourcefn modify_hop(&self, first_hop: FirstHop) -> Result<FirstHop, PickGuardError>
fn modify_hop(&self, first_hop: FirstHop) -> Result<FirstHop, PickGuardError>
Modify first_hop so that it contains no elements not permitted by this
filter.
It is an internal error to call this function on a guard not already
passed by self.permits().