pub(crate) enum DisplayRule {
Sensitive,
Redacted,
}Expand description
What rule do we use when we’re displaying information about a guard?
Variants
Sensitive
The guard is Sensitive; we should display it as “[scrubbed]”.
We use this for public relays on the network, since displaying even the redacted info about them can enough to identify them uniquely within the NetDir.
This should not be too much of a hit for UX (we hope), since the user is not typically expected to work around issues with these guards themself.
Redacted
The guard should be Redacted; we display it as something like “192.x.x.x $ab…”.
We use this for bridges.