pub(crate) struct CircHistory {
n_successes: u32,
n_failures: u32,
n_indeterminate: u32,
}Expand description
The recent history of circuit activity on this guard.
We keep this information so that we can tell if too many circuits are winding up in “indeterminate” status.
What’s this for?
Recall that an “indeterminate” circuit failure is one that might or might not be the guard’s fault. For example, if the second hop of the circuit fails, we can’t tell whether to blame the guard, the second hop, or the internet between them.
But we don’t want to allow an unbounded number of indeterminate failures: if we did, it would allow a malicious guard to simply reject any circuit whose second hop it didn’t like, and thereby filter the client’s paths down to a hostile subset.
So as a workaround, and to discourage this kind of behavior, we track the fraction of indeterminate circuits, and disable any guard where the fraction is too high.
Fields
n_successes: u32How many times have we seen this guard succeed?
n_failures: u32How many times have we seen this guard fail?
n_indeterminate: u32How many times has this guard given us indeterminate results?
Implementations
Sourceimpl CircHistory
impl CircHistory
Sourcefn indeterminate_ratio(&self) -> Option<f64>
fn indeterminate_ratio(&self) -> Option<f64>
If we have seen enough, return the fraction of circuits that have “died under mysterious circumstances”.