pub struct FirstHop {
pub(crate) sample: Option<GuardSetSelector>,
pub(crate) inner: FirstHopInner,
}Expand description
Representation of a guard or fallback, as returned by GuardMgr::select_guard().
Fields
sample: Option<GuardSetSelector>The sample from which this guard was taken, or None if this is a fallback.
inner: FirstHopInnerInformation about connecting to (or through) this guard.
Implementations
Sourceimpl FirstHop
impl FirstHop
Sourcepub(crate) fn first_hop_id(&self) -> FirstHopId
pub(crate) fn first_hop_id(&self) -> FirstHopId
Return a new FirstHopId for this FirstHop.
Sourcepub fn get_relay<'a>(&self, netdir: &'a NetDir) -> Option<Relay<'a>>
pub fn get_relay<'a>(&self, netdir: &'a NetDir) -> Option<Relay<'a>>
Look up this guard in netdir.
Sourcepub fn as_circ_target(&self) -> Option<&OwnedCircTarget>
pub fn as_circ_target(&self) -> Option<&OwnedCircTarget>
If possible, return a view of this object that can be used to build a circuit.
Sourcepub(crate) fn chan_target_mut(&mut self) -> &mut OwnedChanTarget
pub(crate) fn chan_target_mut(&mut self) -> &mut OwnedChanTarget
Return a view of this as an OwnedChanTarget.
Sourcepub(crate) fn lookup_bridge_circ_target(&mut self, bridges: &BridgeSet)
pub(crate) fn lookup_bridge_circ_target(&mut self, bridges: &BridgeSet)
If possible and appropriate, find a circuit target in bridges for this
FirstHop, and make this FirstHop a viable circuit target.
(By default, any FirstHop that a GuardSet returns will have enough
information to be a ChanTarget, but it will be lacking the additional
network information in CircTarget1 necessary for us to build a
multi-hop circuit through it. If this FirstHop is a regular non-bridge
Relay, then the CircMgr will later look up that circuit information
itself from the network directory. But if this FirstHop is a bridge,
then we need to find that information in the BridgeSet, since the
CircMgr does not keep track of the BridgeSet.)
For example, supported protocol versions and ntor keys. ↩
Sourcepub(crate) fn contains_circ_target(&self) -> bool
pub(crate) fn contains_circ_target(&self) -> bool
Return true if this FirstHop contains circuit target information.
This is true if lookup_bridge_circ_target() has been called, and it
successfully found the circuit target information.