pub struct GuardFilter {
filters: Vec<SingleFilter>,
}Expand description
An object specifying which relays are eligible to be guards.
We always restrict the set of possible guards to be the set of
relays currently listed in the consensus directory document, and
tagged with the Guard flag. But clients may narrow the eligible set
even further—for example, to those supporting only a given set of ports,
or to those in a given country.
Fields
filters: Vec<SingleFilter>A list of filters to apply to guard or fallback selection. Each filter restricts which guards may be used, and possibly how those guards may be contacted.
This list of filters has “and” semantics: a relay is permitted by this filter if ALL patterns in this list permit that first hop.
Implementations
Sourceimpl GuardFilter
impl GuardFilter
Sourcepub fn unfiltered() -> Self
pub fn unfiltered() -> Self
Create a new GuardFilter that doesn’t restrict the set of
permissible guards at all.
Sourcepub fn push_reachable_addresses(
&mut self,
addrs: impl IntoIterator<Item = AddrPortPattern>,
)
pub fn push_reachable_addresses( &mut self, addrs: impl IntoIterator<Item = AddrPortPattern>, )
Restrict this filter to only permit connections to an address permitted
by one of the patterns in addrs.
Sourcepub(crate) fn permits<C: ChanTarget>(&self, target: &C) -> bool
pub(crate) fn permits<C: ChanTarget>(&self, target: &C) -> bool
Return true if this filter permits the provided target.
Sourcepub(crate) fn modify_hop(
&self,
first_hop: FirstHop,
) -> Result<FirstHop, PickGuardError>
pub(crate) fn modify_hop( &self, first_hop: FirstHop, ) -> Result<FirstHop, PickGuardError>
Modify first_hop so that it contains no elements not permitted by this
filter.
(For example, if we are restricted only to use certain addresses, then
permits will return true for a guard that has multiple addresses even
if some of those addresses are not permitted. In that scenario, this
method will remove disallowed addresses from first_hop.)
Sourcepub(crate) fn is_unfiltered(&self) -> bool
pub(crate) fn is_unfiltered(&self) -> bool
Return true if this filter excludes no guards at all.
Sourcepub(crate) fn frac_bw_permitted(&self, netdir: &NetDir) -> f64
pub(crate) fn frac_bw_permitted(&self, netdir: &NetDir) -> f64
Return a fraction between 0.0 and 1.0 describing what fraction of the guard bandwidth this filter permits.
Sourcepub(crate) fn add_to_selector(&self, selector: &mut RelaySelector<'_>)
pub(crate) fn add_to_selector(&self, selector: &mut RelaySelector<'_>)
Update selector with all the restrictions from this filter.