pub(crate) struct GuardParams {Show 14 fields
pub(crate) lifetime_unconfirmed: Duration,
pub(crate) lifetime_confirmed: Duration,
pub(crate) lifetime_unlisted: Duration,
pub(crate) max_sample_size: usize,
pub(crate) max_sample_bw_fraction: f64,
pub(crate) min_filtered_sample_size: usize,
pub(crate) n_primary: usize,
pub(crate) data_parallelism: usize,
pub(crate) dir_parallelism: usize,
pub(crate) np_connect_timeout: Duration,
pub(crate) np_idle_timeout: Duration,
pub(crate) internet_down_timeout: Duration,
pub(crate) filter_threshold: f64,
pub(crate) extreme_threshold: f64,
}Expand description
A set of parameters, derived from the consensus document, controlling the behavior of a guard manager.
Fields
lifetime_unconfirmed: DurationHow long should a sampled, un-confirmed guard be kept in the sample before it expires?
lifetime_confirmed: DurationHow long should a confirmed guard be kept in the sample before it expires?
lifetime_unlisted: DurationHow long may a guard be unlisted before we remove it from the sample?
max_sample_size: usizeLargest number of guards we’re willing to add to the sample.
max_sample_bw_fraction: f64Largest fraction of the network’s guard bandwidth that we’re willing to add to the sample.
min_filtered_sample_size: usizeSmallest number of guards that we’re willing to have in the
sample, after applying a GuardFilter.
n_primary: usizeHow many guards are considered “Primary”?
data_parallelism: usizeWhen making a regular circuit, how many primary guards should we be willing to try?
dir_parallelism: usizeWhen making a one-hop directory circuit, how many primary guards should we be willing to try?
np_connect_timeout: DurationFor how long does a pending attempt to connect to a guard block an attempt to use a less-favored non-primary guard?
np_idle_timeout: DurationHow long do we allow a circuit to a successful but unfavored non-primary guard to sit around before deciding not to use it?
internet_down_timeout: DurationAfter how much time without successful activity does a successful circuit indicate that we should retry our primary guards?
filter_threshold: f64What fraction of the guards can be can be filtered out before we decide that our filter is “very restrictive”?
extreme_threshold: f64What fraction of the guards determine that our filter is “very restrictive”?