pub(crate) struct GuardSets {
pub(crate) active_set: GuardSetSelector,
pub(crate) default: GuardSet,
pub(crate) restricted: GuardSet,
pub(crate) bridges: GuardSet,
pub(crate) remaining: HashMap<String, JsonValue>,
}Expand description
Persistent state for a guard manager, as serialized to disk.
Fields
active_set: GuardSetSelectorWhich set of guards is currently in use?
default: GuardSetThe default set of guards to use.
We use this one when there is no filter, or the filter permits most of the guards on the network.
restricted: GuardSetA guard set to use when we have a restrictive filter.
bridges: GuardSetA guard set sampled from our configured bridges.
remaining: HashMap<String, JsonValue>Unrecognized fields, including (possibly) other guard sets.
Implementations
Sourceimpl GuardSets
impl GuardSets
Sourcepub(crate) fn active_guards(&self) -> &GuardSet
pub(crate) fn active_guards(&self) -> &GuardSet
Return a reference to the currently active set of guards.
(That’s easy enough for now, since there is never more than one set of
guards. But eventually that will change, as we add support for more
complex filter types, and for bridge relays. Those will use separate
GuardSet instances, and this accessor will choose the right one.)
Sourcepub(crate) fn guards(&self, selector: &GuardSetSelector) -> &GuardSet
pub(crate) fn guards(&self, selector: &GuardSetSelector) -> &GuardSet
Return the set of guards corresponding to the provided selector.
Sourcepub(crate) fn active_guards_mut(&mut self) -> &mut GuardSet
pub(crate) fn active_guards_mut(&mut self) -> &mut GuardSet
Return a mutable reference to the currently active set of guards.
Sourcepub(crate) fn guards_mut(
&mut self,
selector: &GuardSetSelector,
) -> &mut GuardSet
pub(crate) fn guards_mut( &mut self, selector: &GuardSetSelector, ) -> &mut GuardSet
Return a mutable reference to the set of guards corresponding to the provided selector.
Sourcepub(crate) fn copy_status_from(&mut self, other: GuardSets)
pub(crate) fn copy_status_from(&mut self, other: GuardSets)
Update all non-persistent state for the guards in this object with the
state in other.