pub struct SkewEstimate {
estimate: ClockSkew,
n_observations: usize,
confidence: Confidence,
}Expand description
An estimate of how skewed our clock is, plus a summary of why we think so.
Fields
estimate: ClockSkewOur best guess for the magnitude of the skew.
n_observations: usizeThe number of observations leading to this estimate.
confidence: ConfidenceA description of how confident we are.
Implementations
Sourceimpl SkewEstimate
impl SkewEstimate
Sourcepub fn noteworthy(&self) -> bool
pub fn noteworthy(&self) -> bool
Return true if this estimate is worth telling the user about.
Sourcepub(crate) fn estimate_skew<'a>(
skews: impl Iterator<Item = &'a SkewObservation>,
now: Instant,
) -> Option<Self>
pub(crate) fn estimate_skew<'a>( skews: impl Iterator<Item = &'a SkewObservation>, now: Instant, ) -> Option<Self>
Compute an estimate of how skewed we think our clock is, based on the
reports in skews.