round_time

Function round_time 

fn round_time(when: SystemTime, d: u32) -> SystemTime
Round when to a multiple of d seconds relative to epoch.

Rounds towards the epoch.

There’s no reason to actually do this, since the times we use it on are randomized, but rounding times in this way avoids giving a false impression that we’re storing hyper-accurate numbers.

Panics

Panics if d == 0.