pub(super) struct VanguardSets {
l2_vanguards: VanguardSet,
l3_vanguards: VanguardSet,
}Expand description
The L2 and L3 vanguard sets, stored in the same struct to simplify serialization.
Fields
l2_vanguards: VanguardSetThe L2 vanguard sets.
l3_vanguards: VanguardSetThe L3 vanguard sets.
Only used if full vanguards are enabled.
Implementations
Sourceimpl VanguardSets
impl VanguardSets
Sourcepub(super) fn next_expiry(&self) -> Option<SystemTime>
pub(super) fn next_expiry(&self) -> Option<SystemTime>
Find the timestamp of the vanguard that is due to expire next.
Sourcepub(super) fn l2(&self) -> &VanguardSet
pub(super) fn l2(&self) -> &VanguardSet
Return a reference to the L2 VanguardSet.
Sourcepub(super) fn l3(&self) -> &VanguardSet
pub(super) fn l3(&self) -> &VanguardSet
Return a reference to the L3 VanguardSet.
Sourcepub(super) fn remove_expired(&mut self, now: SystemTime) -> usize
pub(super) fn remove_expired(&mut self, now: SystemTime) -> usize
Remove the vanguards that are expired at the specified timestamp.
Returns the number of vanguards that were removed.
Sourcepub(super) fn remove_unlisted(&mut self, netdir: &NetDir)
pub(super) fn remove_unlisted(&mut self, netdir: &NetDir)
Remove the vanguards that are no longer listed in netdir.
Returns whether either of the two sets have changed.
Sourcepub(super) fn replenish_vanguards<R: Runtime>(
&mut self,
runtime: &R,
netdir: &NetDir,
params: &VanguardParams,
mode: VanguardMode,
) -> Result<(), VanguardMgrError>
pub(super) fn replenish_vanguards<R: Runtime>( &mut self, runtime: &R, netdir: &NetDir, params: &VanguardParams, mode: VanguardMode, ) -> Result<(), VanguardMgrError>
Sourcefn replenish_set<R: Runtime, Rng: RngCore>(
runtime: &R,
rng: &mut Rng,
netdir: &NetDir,
vanguard_set: &mut VanguardSet,
min_lifetime: Duration,
max_lifetime: Duration,
) -> Result<bool, VanguardMgrError>
fn replenish_set<R: Runtime, Rng: RngCore>( runtime: &R, rng: &mut Rng, netdir: &NetDir, vanguard_set: &mut VanguardSet, min_lifetime: Duration, max_lifetime: Duration, ) -> Result<bool, VanguardMgrError>
Replenish a single VanguardSet with however many vanguards it is short of.
Sourcefn add_n_vanguards<R: Runtime, Rng: RngCore>(
runtime: &R,
rng: &mut Rng,
netdir: &NetDir,
n: usize,
exclude: RelayExclusion<'_>,
min_lifetime: Duration,
max_lifetime: Duration,
) -> Result<Vec<TimeBoundVanguard>, VanguardMgrError>
fn add_n_vanguards<R: Runtime, Rng: RngCore>( runtime: &R, rng: &mut Rng, netdir: &NetDir, n: usize, exclude: RelayExclusion<'_>, min_lifetime: Duration, max_lifetime: Duration, ) -> Result<Vec<TimeBoundVanguard>, VanguardMgrError>
Select n relays to use as vanguards.
Each selected vanguard will have a random lifetime
between min_lifetime and max_lifetime.