struct Inner {
params: VanguardParams,
mode: VanguardMode,
vanguard_sets: VanguardSets,
has_onion_svc: bool,
config_tx: Sender<VanguardConfig>,
}Expand description
The mutable inner state of VanguardMgr.
Fields
params: VanguardParamsThe current vanguard parameters.
mode: VanguardModeWhether to use full, lite, or no vanguards.
vanguard_sets: VanguardSetsThe L2 and L3 vanguards.
The L3 vanguards are only used if we are running in
Full vanguard mode.
Otherwise, the L3 set is not populated, or read from.
If Full vanguard mode is enabled,
the vanguard sets will be persisted to disk whenever
vanuards are rotated, added, or removed.
The vanguard sets are updated and persisted to storage by
update_vanguard_sets.
If the VanguardSets change while we are in “lite” mode,
the changes will not not be written to storage.
If we later switch to “full” vanguards, those previous changes still
won’t be persisted to storage: we only flush to storage if the
VanguardSets change while we are in “full” mode
(changing the VanguardMode does not constitute a change in the VanguardSets).
This is initialized with the vanguard sets read from the vanguard state file,
if the file exists, or with a Default VanguardSets, if it doesn’t.
Note: The VanguardSets are read from the vanguard state file
even if full vanguards are not enabled. They are not, however, written
to the state file unless full vanguards are in use.
has_onion_svc: boolWhether we’re running an onion service.
config_tx: Sender<VanguardConfig>A channel for sending VanguardConfig changes to the vanguard maintenance task.
Implementations
Sourceimpl Inner
impl Inner
Sourcefn update_vanguard_sets<R: Runtime>(
&mut self,
runtime: &R,
storage: &DynStorageHandle<VanguardSets>,
netdir: &Arc<NetDir>,
) -> Result<(), VanguardMgrError>
fn update_vanguard_sets<R: Runtime>( &mut self, runtime: &R, storage: &DynStorageHandle<VanguardSets>, netdir: &Arc<NetDir>, ) -> Result<(), VanguardMgrError>
Update the vanguard sets, handling any potential vanguard parameter changes.
This updates the VanguardSetss based on the VanguardParams
derived from the new NetDir, replenishing the sets if necessary.
NOTE: if the new VanguardParams specify different lifetime ranges
than the previous VanguardParams, the new lifetime requirements only
apply to newly selected vanguards. They are not retroactively applied
to our existing vanguards.
Sourcefn update_params(&mut self, new_params: VanguardParams)
fn update_params(&mut self, new_params: VanguardParams)
Update our vanguard params.
Sourcefn flush_to_storage(
&self,
storage: &DynStorageHandle<VanguardSets>,
) -> Result<(), VanguardMgrError>
fn flush_to_storage( &self, storage: &DynStorageHandle<VanguardSets>, ) -> Result<(), VanguardMgrError>
Flush the vanguard sets to storage, if the mode is “vanguards-full”.